<?php
// vim: foldmethod=marker
/**
 *  {$project_id}_ViewClass.php
 *
 *  @author     {$author}
 *  @package    {$project_id}
 *  @version    $Id: app.viewclass.php 600 2008-06-30 23:12:42Z mumumu-org $
 */

// {{{ {$project_id}_ViewClass
/**
 *  View class.
 *
 *  @author     {$author}
 *  @package    {$project_id}
 *  @access     public
 */
class {$project_id}_ViewClass extends Ethna_ViewClass
{
    /**
     *  set common default value.
     *
     *  @access protected
     *  @param  object  {$project_id}_Renderer  Renderer object.
     */
    function _setDefault(&$renderer)
    {
    }

    /**
     *  set language using actionform value, cookie ... etc.
     *
     *  @access protected
     */
    function _setLanguage()
    {
    }
}
// }}}

?>
